@@ -1,4 +1,4 @@
-/*$Id: common.js,v 1.10 2007/03/23 19:35:19 jwrobel Exp $*/
+/*$Id: common.js,v 1.11 2007/03/24 16:26:22 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -36,7 +36,7 @@ var debug = {
 	
 	msg: function(s){
 		this.console.logStringMessage(s);
-		dump(s + "\n");
+		//dump(s + "\n");
 	},
 	
 	assert: function(val, str){
