@@ -1,4 +1,4 @@
-/*$Id: firekeeper.js,v 1.15 2006/12/14 10:21:16 jwrobel Exp $*/
+/*$Id: firekeeper.js,v 1.17 2007/02/15 16:00:42 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -141,8 +141,11 @@ function firekeeperInit(event)
 
 function openConfigWindow()
 {
-	window.open('chrome://firekeeper/content/config.xul', '_blank', 
-		    'chrome,dialog=no,resizable,centerscreen');
+	//window.openDialog('chrome://firekeeper/content/config.xul', 'preferences', 
+	//	  'chrome,resizable,centerscreen,dialog=no');
+	window.openDialog('chrome://firekeeper/content/config.xul', '_blank', 
+		    'chrome,modal=yes,resizable,centerscreen');
+	
 }
 
 function changeEnable()
