@@ -1,4 +1,4 @@
-/*$Id: fkHttpHandler.cpp,v 1.20 2006/11/04 21:09:25 jwrobel Exp $*/
+/*$Id: fkHttpHandler.cpp,v 1.23 2007/03/15 23:34:47 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -150,6 +150,7 @@ fkHttpHandler::NewURI(const nsACString &aSpec,
 NS_IMETHODIMP
 fkHttpHandler::NewChannel(nsIURI *uri, nsIChannel **result)
 {
+	TRACE("no proxy");
 	/*Create ProxiedChannel without proxy*/
 	return this->NewProxiedChannel(uri, nsnull, result);
 }
@@ -177,9 +178,12 @@ fkHttpHandler::NewProxiedChannel(nsIURI *uri,
 {
 	nsresult rv;	
 	nsEmbedCString s;
+	TRACE("proxy info = %08x", givenProxyInfo);
 	if (!tracingEnabled || fkJudge == nsnull){
 		TRACE("not tracing new channel");
-		return origHandler->NewChannel(uri, result);
+		return origProxiedHandler->NewProxiedChannel(uri, 
+							     givenProxyInfo,
+							     result);
 	}
 	
 	fkSentence *sentence_raw = new fkSentence();
@@ -247,6 +251,8 @@ fkHttpHandler::NewProxiedChannel(nsIURI *uri,
 		return NS_ERROR_OUT_OF_MEMORY;
 	}
 	NS_ADDREF(fkChannel);	
+
+	/*TODO: NULL pointer check*/
 	*result = fkChannel;
 
 	return NS_OK;
